# pyOSPParser
Python modules for parsing and deploying the xml/json files used in the 
[Open Simulation Platform](https://opensimulationplatform.com). The module
can parse the following xml/json files for the simulation.
  - OSP model description file (XXX_OspModelDescription.xml)
  - OSP system structure file (OspSystemStructure.xml)
  - OSP logging configuration file (LogConfig.xml)
  - OSP scenario configuration file (XXX.json)  

# Getting Started
## Installation
pyOSPParser requires Python 3.7 or later. Primarily, you can install pyOSPParser by pip:
```bash
pip install pyospparser
``` 
